==> billogram-foundation-4.6.0.tgz: package/modules/components/ContainerWrapper.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import { connect } from 'react-redux';
import invariant from 'invariant';

import getComponentState from '../utils/getComponentState';


export default ({
    Component,
    mapDispatchToProps = null,
    mapStateToProps = getComponentState
} = {}) => {

    invariant(Component !== undefined, 'Missing `Component`.');

    const Container = React.createClass({

        displayName: `${Component.displayName}Container`,

        mixins: [PureRenderMixin],

        propTypes: {
            actionTypePrefix: PropTypes.string,
            componentRef: PropTypes.func,
            customActionMetadata: PropTypes.object,
            path: PropTypes.string,
            root: PropTypes.string
        },

        getDefaultProps() {
            return {
                componentRef: null
            };
        },

        render() {
            const {
                /* eslint-disable no-unused-vars */
                actionTypePrefix,
                componentRef,
                customActionMetadata,
                path,
                root,
                /* eslint-enable no-unused-vars */
                ...otherProps
            } = this.props;

            return (
                <Component
                    { ...otherProps }
                    ref={ componentRef } />
            );
        }

    });

    return connect(mapStateToProps, mapDispatchToProps)(Container);
};

==> billogram-foundation-4.7.7.tgz: package/modules/components/ContainerWrapper.js <==
import React, { PropTypes } from 'react';
import PureRenderMixin from 'react-addons-pure-render-mixin';
import { connect } from 'react-redux';
import invariant from 'invariant';

import getComponentState from '../utils/getComponentState';


export default ({
    Component,
    mapDispatchToProps = null,
    mapStateToProps = getComponentState,
} = {}) => {

    invariant(Component !== undefined, 'Missing `Component`.');

    const Container = React.createClass({

        displayName: `${Component.displayName}Container`,

        mixins: [PureRenderMixin],

        propTypes: {
            actionTypePrefix: PropTypes.string,
            componentRef: PropTypes.func,
            customActionMetadata: PropTypes.object,
            path: PropTypes.string,
            root: PropTypes.string,
        },

        getDefaultProps() {
            return {
                componentRef: null,
            };
        },

        render() {
            const {
                /* eslint-disable no-unused-vars */
                actionTypePrefix,
                componentRef,
                customActionMetadata,
                path,
                root,
                /* eslint-enable no-unused-vars */
                ...otherProps
            } = this.props;

            return (
                <Component
                    { ...otherProps }
                    ref={ componentRef } />
            );
        },

    });

    return connect(mapStateToProps, mapDispatchToProps)(Container);
};
